import { DataV2 } from "@metaplex-foundation/mpl-token-metadata";
import { Provider } from "@project-serum/anchor";
import { Finality, PublicKey, Keypair } from "@solana/web3.js";
import { SplTokenBonding, ICreateTokenBondingArgs } from "@strata-foundation/spl-token-bonding";
import { BigInstructionResult, InstructionResult, SplTokenMetadata } from "@strata-foundation/spl-utils";
interface ICreateMarketItemArgs {
    payer?: PublicKey;
    /**
     * Optionally, use this keypair to create the target mint
     */
    targetMintKeypair?: Keypair;
    /**
     * Wallet who will receive the proceeds of this sale. **Default:** provider wallet publicKey
     */
    seller?: PublicKey;
    /**
     * Account to deposit the resulting funds in. **Default:** ATA on seller
     */
    salesAccount?: PublicKey;
    /**
     * The update authority on the metadata created. **Default:** Seller
     */
    metadataUpdateAuthority?: PublicKey;
    /**
     * The token metadata for the marketplace item
     */
    metadata: DataV2;
    /**
     * The quantity to stop selling at
     */
    quantity?: number;
    /**
     * The price to sell them for. If not provided, should pass `bondingArgs.curve`
     */
    price?: number;
    /**
     * The mint to base the sales off of
     */
    baseMint: PublicKey;
    /**
     * Optionally -- override bonding params
     */
    bondingArgs?: ICreateTokenBondingArgs;
}
interface ICreateMetadataForBondingArgs {
    /**
     * The update authority on the metadata created. **Default:** Seller
     */
    metadataUpdateAuthority?: PublicKey;
    /**
     * The token metadata for the marketplace item
     */
    metadata: DataV2;
    /**
     * Optionally, use this keypair to create the target mint
     */
    targetMintKeypair?: Keypair;
}
export declare class MarketplaceSdk {
    readonly provider: Provider;
    readonly tokenBondingSdk: SplTokenBonding;
    readonly tokenMetadataSdk: SplTokenMetadata;
    static init(provider: Provider, splTokenBondingProgramId?: PublicKey): Promise<MarketplaceSdk>;
    constructor(provider: Provider, tokenBondingSdk: SplTokenBonding, tokenMetadataSdk: SplTokenMetadata);
    createMetadataForBondingInstructions({ metadataUpdateAuthority, metadata, targetMintKeypair, }: ICreateMetadataForBondingArgs): Promise<InstructionResult<{
        metadata: PublicKey;
        mint: PublicKey;
    }>>;
    /**
     * Creates a market item selling a quantity qty for a price
     *
     * @param param0
     * @returns
     */
    createMarketItemInstructions({ payer, seller, metadata, metadataUpdateAuthority, quantity, price, bondingArgs, baseMint, }: ICreateMarketItemArgs): Promise<BigInstructionResult<{
        tokenBonding: PublicKey;
    }>>;
    /**
     * Executes `createMarketItemIntructions`
     * @param args
     * @returns
     */
    createMarketItem(args: ICreateMarketItemArgs, finality?: Finality): Promise<{
        tokenBonding: PublicKey;
    }>;
}
export {};
//# sourceMappingURL=index.d.ts.map